import { e } from "unocss";
function presetBootstrapGrid(options = {}) {
  var _a, _b, _c;
  const prefix = (_a = options.prefix) != null ? _a : "b-";
  const gutter = (_b = options.gutter) != null ? _b : "1rem";
  const gridColumns = (_c = options.gridColumns) != null ? _c : 12;
  return {
    name: "unocss-preset-bootstrap-grid",
    rules: [
      [`${prefix}container`, {
        "width": "100%",
        "margin-right": "auto",
        "margin-left": "auto"
      }],
      [
        new RegExp(`^${prefix}row$`),
        ([], { rawSelector }) => {
          const selector = e(rawSelector);
          const template = `
            .${selector} {
              display: flex;
              flex-wrap: wrap;
              /* TODO: Revisit calc order after https://github.com/react-bootstrap/react-bootstrap/issues/6039 is fixed */
              margin-top: calc(-1 * var(--${prefix}gutter-y, 0));
              margin-right: calc(-.5 * var(--${prefix}gutter-x, ${gutter}));
              margin-left: calc(-.5 * var(--${prefix}gutter-x, ${gutter}));
            }
            .${selector} > * {
              flex-shrink: 0;
              width: 100%;
              max-width: 100%;
              padding-right: calc(var(--${prefix}gutter-x, ${gutter}) * .5);
              padding-left: calc(var(--${prefix}gutter-x, ${gutter}) * .5);
              margin-top: var(--${prefix}gutter-y);
            }
          `;
          return template.replace(/^ {12}/gm, "");
        }
      ],
      [
        new RegExp(`^${prefix}col-?(\\d*)$`),
        ([, size]) => {
          if (size)
            return {
              "flex": "0 0 auto",
              "width": `${size / gridColumns * 100}%`
            };
          else
            return {
              "flex": "1 0 0%"
            };
        }
      ],
      [`${prefix}col-auto`, {
        "flex": "0 0 auto",
        "width": "auto"
      }],
      [
        new RegExp(`^${prefix}col-offset-(\\d+)$`),
        ([, size]) => {
          return {
            "margin-left": size === "0" ? 0 : `${size / gridColumns * 100}%`
          };
        }
      ],
      [
        new RegExp(`^${prefix}row-cols-(\\d+|auto)$`),
        ([, columns], { rawSelector }) => {
          const selector = e(rawSelector);
          const template = `
            .${selector} > * { 
              flex: 0 0 auto;
              width: ${columns === "auto" ? "auto" : `${100 / columns}%`};
            }
          `;
          return template.replace(/^ {12}/gm, "");
        }
      ],
      [
        new RegExp(`^${prefix}g(x|y)?-(\\d+)$`),
        ([, dim, size]) => {
          let returnObj = {};
          if (dim !== "y")
            returnObj[`--${prefix}gutter-x`] = `${0.25 * size}rem`;
          if (dim !== "x")
            returnObj[`--${prefix}gutter-y`] = `${0.25 * size}rem`;
          return returnObj;
        }
      ]
    ]
  };
}
export { presetBootstrapGrid as default, presetBootstrapGrid };
